website-worth
=============

Install
-------

### From pip
This app works from Python 3.5 and the best choice is installation using pip

```
pip install --user website-worth
```

How to use
----------

Run:
```
website_worth run https://example.com
```
